from fontTools.misc.py23 import *
import sys
from fontTools.subset import main

if __name__ == '__main__':
    sys.exit(main())
